==> nextcloud-30.0.2.tgz: nextcloud/apps/user_status/l10n/nl.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Recente statussen",
    "No recent status changes" : "Geen recente statuswijzigingen",
    "In a meeting" : "In een vergadering",
    "Commuting" : "Woon-werk",
    "Out sick" : "Ziek",
    "Vacationing" : "Op vakantie",
    "Out of office" : "Niet op kantoor",
    "Working remotely" : "Thuiswerken",
    "In a call" : "In gesprek",
    "User status" : "Gebruikersstatus",
    "Clear status after" : "Maak de status leeg na",
    "What is your status?" : "Wat is jouw status?",
    "Set status" : "Status instellen",
    "Online status" : "Online status",
    "Status message" : "Statusbericht",
    "Clear status message" : "Statusbericht wissen",
    "Set status message" : "Statusbericht instellen",
    "There was an error saving the status" : "Er is een fout opgetreden bij het bewaren van de status",
    "There was an error clearing the status" : "Er is een fout opgetreden bij het leegmaken van de status",
    "Don't clear" : "Niet schoonmaken",
    "Today" : "Vandaag",
    "This week" : "Deze week",
    "Online" : "Online",
    "Away" : "Afwezig",
    "Do not disturb" : "Niet storen",
    "Invisible" : "Verborgen",
    "Offline" : "Off-line",
    "There was an error saving the new status" : "Er is een fout opgetreden bij het bewaren van de nieuwe status",
    "30 minutes" : "30 minuten",
    "1 hour" : "1 uur",
    "4 hours" : "4 uur",
    "Mute all notifications" : "Onderdruk alle meldingen",
    "Appear offline" : "Toon afwezig"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/user_status/l10n/nl.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Recente statussen",
    "No recent status changes" : "Geen recente statuswijzigingen",
    "In a meeting" : "In een vergadering",
    "Commuting" : "Woon-werk",
    "Out sick" : "Ziek",
    "Vacationing" : "Op vakantie",
    "Out of office" : "Niet op kantoor",
    "Working remotely" : "Thuiswerken",
    "In a call" : "In gesprek",
    "User status" : "Gebruikersstatus",
    "Clear status after" : "Maak de status leeg na",
    "Emoji for your status message" : "Emoji voor je statusbericht",
    "What is your status?" : "Wat is jouw status?",
    "Predefined statuses" : "Voorgedefinieerde statussen",
    "Previously set" : "Eerder ingesteld",
    "Reset status" : "Reset status",
    "Set status" : "Status instellen",
    "Online status" : "Online status",
    "Status message" : "Statusbericht",
    "Your status was set automatically" : "Uw status is automatisch ingesteld",
    "Clear status message" : "Statusbericht wissen",
    "Set status message" : "Statusbericht instellen",
    "There was an error saving the status" : "Er is een fout opgetreden bij het bewaren van de status",
    "There was an error clearing the status" : "Er is een fout opgetreden bij het leegmaken van de status",
    "Don't clear" : "Niet schoonmaken",
    "Today" : "Vandaag",
    "This week" : "Deze week",
    "Online" : "Online",
    "Away" : "Afwezig",
    "Do not disturb" : "Niet storen",
    "Invisible" : "Verborgen",
    "Offline" : "Off-line",
    "There was an error saving the new status" : "Er is een fout opgetreden bij het bewaren van de nieuwe status",
    "30 minutes" : "30 minuten",
    "1 hour" : "1 uur",
    "4 hours" : "4 uur",
    "Mute all notifications" : "Onderdruk alle meldingen",
    "Appear offline" : "Toon afwezig"
},
"nplurals=2; plural=(n != 1);");
